==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/content/messages/de/richtexteditor.php <==
<?php
return array (
  'Activity' => 'Aktivität',
  'Add or remove link' => 'Verweis hinzufügen oder entfernen',
  'Animals & Nature' => 'Tiere und Natur',
  'Change to code block' => 'Umwandeln in Codeblock',
  'Change to heading' => 'Umwandeln in Überschrift',
  'Change to paragraph' => 'Umwandeln in Textabsatz',
  'Code' => 'Code',
  'Columns' => 'Spalten',
  'Create a link' => 'Verweis erstellen',
  'Create table' => 'Tabelle erstellen',
  'Delete column' => 'Spalte löschen',
  'Delete row' => 'Zeile löschen',
  'Delete table' => 'Tabelle löschen',
  'Flags' => 'Flaggen',
  'Food & Drink' => 'Essen und Trinken',
  'Heading' => 'Überschrift',
  'Height' => 'Höhe',
  'Horizontal rule' => 'Horizontale Linie',
  'Image' => 'Bild',
  'Insert' => 'Einfügen',
  'Insert column after' => 'Spalte einfügen nach',
  'Insert column before' => 'Spalte einfügen davor',
  'Insert horizontal rule' => 'Horizontale Linie einfügen',
  'Insert image' => 'Bild einfügen',
  'Insert row after' => 'Zeile einfügen nach',
  'Insert row before' => 'Zeile einfügen davor',
  'Insert table' => 'Tabelle einfügen',
  'Link target' => 'Verweisziel',
  'Location' => 'Ort',
  'Objects' => 'Objekte',
  'Paragraph' => 'Absätze',
  'People' => 'Mitglieder',
  'Rows' => 'Zeilen',
  'Symbols' => 'Symbole',
  'Title' => 'Titel',
  'Toggle code font' => 'Schriftart ein- bzw. ausschalten',
  'Toggle emphasis' => 'Hervorhebung ein- bzw. ausschalten',
  'Toggle strikethrough' => 'Durchgestrichen ein- bzw. ausschalten',
  'Toggle strong style' => 'Fett ein- bzw. ausschalten',
  'Travel & Places' => 'Reisen und Orte',
  'Type' => 'Typ',
  'Upload File' => 'Datei hochladen',
  'Upload and include a File' => 'Datei hochladen und einbinden',
  'Width' => 'Weite',
  'Wrap in block quote' => 'Als Zitat darstellen',
  'Wrap in bullet list' => 'Als Aufzählungsliste darstellen',
  'Wrap in ordered list' => 'Als nummerierte Liste darstellen',
  '[Code Block]' => '[Code-Block]',
  '[Image]' => '[Bild]',
  '[Invalid file]' => '[Ungültige Datei]',
  '[Table]' => '[Tabelle]',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/content/messages/de/richtexteditor.php <==
<?php
return array (
  'Activity' => 'Aktivität',
  'Add or remove link' => 'Verweis hinzufügen oder entfernen',
  'Animals & Nature' => 'Tiere und Natur',
  'Change to code block' => 'Umwandeln in Codeblock',
  'Change to heading' => 'Umwandeln in Überschrift',
  'Change to paragraph' => 'Umwandeln in Textabsatz',
  'Code' => 'Code',
  'Columns' => 'Spalten',
  'Create a link' => 'Verweis erstellen',
  'Create table' => 'Tabelle erstellen',
  'Delete column' => 'Spalte löschen',
  'Delete row' => 'Zeile löschen',
  'Delete table' => 'Tabelle löschen',
  'Flags' => 'Flaggen',
  'Food & Drink' => 'Essen und Trinken',
  'Heading' => 'Überschrift',
  'Height' => 'Höhe',
  'Horizontal rule' => 'Horizontale Linie',
  'Image' => 'Bild',
  'Insert' => 'Einfügen',
  'Insert column after' => 'Spalte einfügen nach',
  'Insert column before' => 'Spalte einfügen davor',
  'Insert horizontal rule' => 'Horizontale Linie einfügen',
  'Insert image' => 'Bild einfügen',
  'Insert row after' => 'Zeile einfügen nach',
  'Insert row before' => 'Zeile einfügen davor',
  'Insert table' => 'Tabelle einfügen',
  'Link target' => 'Verweisziel',
  'Location' => 'Ort',
  'Objects' => 'Objekte',
  'Paragraph' => 'Absätze',
  'People' => 'Mitglieder',
  'Rows' => 'Zeilen',
  'Symbols' => 'Symbole',
  'Title' => 'Titel',
  'Toggle code font' => 'Code-Schriftart ein- bzw. ausschalten',
  'Toggle emphasis' => 'Hervorhebung ein- bzw. ausschalten',
  'Toggle strikethrough' => 'Durchgestrichen ein- bzw. ausschalten',
  'Toggle strong style' => 'Fett ein- bzw. ausschalten',
  'Travel & Places' => 'Reisen und Orte',
  'Type' => 'Typ',
  'Upload File' => 'Datei hochladen',
  'Upload and include a File' => 'Datei hochladen und einbinden',
  'Width' => 'Weite',
  'Wrap in block quote' => 'Als Zitat darstellen',
  'Wrap in bullet list' => 'Als Aufzählungsliste darstellen',
  'Wrap in ordered list' => 'Als nummerierte Liste darstellen',
  '[Code Block]' => '[Code-Block]',
  '[Image]' => '[Bild]',
  '[Invalid file]' => '[Ungültige Datei]',
  '[Table]' => '[Tabelle]',
);
